@@ -17,13 +17,15 @@ except ImportError:
 
 class FylexConfig:
     MAX_RETRIES = 5
-    ON_CONFLICT_MODES = ["larger", "smaller", "newer", "older","rename", "skip", "prompt", "replace"]
+    ON_CONFLICT_MODES = ["larger", "smaller", "newer", "older", "rename", "skip", "prompt", "replace"]
     DEFAULT_CHUNK_SIZE = 16 * 1024 * 1024
     DEFAULT_HASH_ALGO = "xxhash"
-    DB_FILE = "file_cache.db"
+    FYLEX_HOME = Path.home() / ".fylex"
+    FYLEX_HOME.mkdir(parents=True, exist_ok=True)
     TABLE_NAME = "file_hashes"
+    DB_FILE = "file_cache.db"
+    DB_PATH = FYLEX_HOME / DB_FILE 
     DB_CONN = None
-    DB_PATH = DB_FILE
     DB_LOCK = threading.Lock()
     LOG_MODE = "jsonl"
 
@@ -655,9 +657,6 @@ def copy_with_conflict_resolution(mode: str, src: Path | str, dest: Path | str,
     if isinstance(action, Path):
         save_as = action
         logging.info(f"[RENAME] Renaming copy target: {src} -> {action}")
-        if (dest_file.is_file()):
-            logging.info(f"[DEPRECATE] {dest_file} is deprecated. Transferring it to: {save_as}")
-            fast_move(dest_file, save_as, algo, dry_run)
         copier(src, action, get_optimal_buffer_size(src), algo, preserve_meta, mode, dry_run)
         if (verify):
             if (get_or_update_file_hash(src, algo) != get_or_update_file_hash(action, algo)):
@@ -864,7 +863,7 @@ def filemove(src: Path | str, dest: Path | str, resolve: str = "rename", algo: s
                    exclude_regex, exclude_names, exclude_glob, recursive_check, recurse,
                    verify, has_extension, no_create, preserve_meta, backup)
 
-def undo(p_id: str, verbose: bool = True, force: bool = False) -> bool:
+def undo(p_id: str, verbose: bool = True, force: bool = False, summary: Path | str = None) -> bool:
     global state
     safe_logging(verbose)
     func_name = "undo"
@@ -956,11 +955,11 @@ def undo(p_id: str, verbose: bool = True, force: bool = False) -> bool:
     else:
         logging.info(f"[UNDO] Process {p_id} undone successfully")
 
-    state = FylexState()
+    log_copier(func_name, summary)
     return True
 
 
-def redo(p_id: str, verbose: bool = True, force: bool = False) -> bool:
+def redo(p_id: str, verbose: bool = True, force: bool = False, summary: Path | str = None) -> bool:
     global state
     safe_logging(verbose)
     func_name = "redo"
@@ -1042,5 +1041,5 @@ def redo(p_id: str, verbose: bool = True, force: bool = False) -> bool:
     else:
         logging.info(f"[REDO] Process {p_id} replayed successfully")
 
-    state = FylexState()
+    log_copier(func_name, summary)
     return True
